@@ -107,7 +107,6 @@ do
       (cd lang/ruby; ./build.sh lint test)
       (cd lang/php; ./build.sh lint test)
       (cd lang/perl; ./build.sh lint test)
-      (cd lang/rust; ./build.sh lint test)
 
       (cd lang/py; ./build.sh interop-data-generate)
       (cd lang/c; ./build.sh interop-data-generate)
@@ -157,6 +156,9 @@ do
       # runs RAT on artifacts
       mvn -N -P rat antrun:run verify
 
+      # install java artifacts required by other builds and interop tests
+      mvn -B install -DskipTests
+
       mkdir -p dist
       (cd build; tar czf "../dist/${SRC_DIR}.tar.gz" "${SRC_DIR}")
 
@@ -173,7 +175,6 @@ do
       (cd lang/js; ./build.sh dist)
       (cd lang/ruby; ./build.sh dist)
       (cd lang/php; ./build.sh dist)
-      (cd lang/rust; ./build.sh dist)
 
       mkdir -p dist/perl
       (cd lang/perl; ./build.sh dist)
@@ -183,7 +184,7 @@ do
       cp -r doc/ build/staging-web/
       find build/staging-web/ -type f -print0 | xargs -0 sed -r -i "s#\+\+version\+\+#${VERSION,,}#g"
       mkdir -p build/staging-web/public/docs/
-      mv build/staging-web/doc/content/en/docs/++version++ build/staging-web/public/docs/"${VERSION,,}"
+      mv build/staging-web/content/en/docs/++version++ build/staging-web/public/docs/"${VERSION,,}"
       read -n 1 -s -r -p "Build build/staging-web/ manually now. Press a key to continue..."
       # If it was a SNAPSHOT, it was lowercased during the build.
       cp -R build/staging-web/public/docs/"${VERSION,,}"/* "build/$DOC_DIR/"
@@ -249,7 +250,6 @@ do
 
       (cd lang/perl; ./build.sh clean)
 
-      (cd lang/rust; ./build.sh clean)
       ;;
 
     veryclean)
@@ -277,8 +277,6 @@ do
 
       (cd lang/perl; ./build.sh clean)
 
-      (cd lang/rust; ./build.sh clean)
-
       rm -rf lang/c++/build
       rm -rf lang/js/node_modules
       rm -rf lang/perl/inc/
@@ -289,6 +287,7 @@ do
       ;;
 
     docker)
+      echo "NB: for Docker Desktop users on MacOS, the default file sharing implementation (VirtioFS) has issues with some operations. You should better use gRPC FUSE or osxfs."
       if [[ $1 =~ ^--args ]]; then
         DOCKER_RUN_XTRA_ARGS=$2
         shift 2
