@@ -51,8 +51,11 @@ class Name:
     """Class to describe Avro name."""
 
     _full: Optional[str] = None
+    _name: Optional[str] = None
 
-    def __init__(self, name_attr: Optional[str] = None, space_attr: Optional[str] = None, default_space: Optional[str] = None) -> None:
+    def __init__(
+        self, name_attr: Optional[str] = None, space_attr: Optional[str] = None, default_space: Optional[str] = None, validate_name: bool = True
+    ) -> None:
         """The fullname is determined in one of the following ways:
 
         - A name and namespace are both specified. For example, one might use "name": "X",
@@ -80,17 +83,23 @@ class Name:
         if name_attr == "":
             raise avro.errors.SchemaParseException("Name must not be the empty string.")
         # The empty string may be used as a namespace to indicate the null namespace.
+        self._name = name_attr.split(".")[-1]
         self._full = (
             name_attr
             if "." in name_attr or space_attr == "" or not (space_attr or default_space)
             else f"{space_attr or default_space!s}.{name_attr!s}"
         )
-        _validate_fullname(self._full)
+        if validate_name:
+            _validate_fullname(self._full)
 
     def __eq__(self, other: object) -> bool:
         """Equality of names is defined on the fullname and is case-sensitive."""
         return hasattr(other, "fullname") and self.fullname == getattr(other, "fullname")
 
+    @property
+    def name(self) -> Optional[str]:
+        return self._name
+
     @property
     def fullname(self) -> Optional[str]:
         return self._full
@@ -111,16 +120,17 @@ class Names:
 
     names: Dict[str, "NamedSchema"]
 
-    def __init__(self, default_namespace: Optional[str] = None) -> None:
+    def __init__(self, default_namespace: Optional[str] = None, validate_names: bool = True) -> None:
         self.names = {}
         self.default_namespace = default_namespace
+        self.validate_names = validate_names
 
     def has_name(self, name_attr: str, space_attr: Optional[str] = None) -> bool:
-        test = Name(name_attr, space_attr, self.default_namespace).fullname
+        test = Name(name_attr, space_attr, self.default_namespace, validate_name=self.validate_names).fullname
         return test in self.names
 
     def get_name(self, name_attr: str, space_attr: Optional[str] = None) -> Optional["NamedSchema"]:
-        test = Name(name_attr, space_attr, self.default_namespace).fullname
+        test = Name(name_attr, space_attr, self.default_namespace, validate_name=self.validate_names).fullname
         return None if test is None else self.names.get(test)
 
     def prune_namespace(self, properties: Dict[str, object]) -> Dict[str, object]:
@@ -152,7 +162,7 @@ class Names:
 
         @return: the Name that was just added.
         """
-        to_add = Name(name_attr, space_attr, self.default_namespace)
+        to_add = Name(name_attr, space_attr, self.default_namespace, validate_name=self.validate_names)
 
         if to_add.fullname in PRIMITIVE_TYPES:
             raise avro.errors.SchemaParseException(f"{to_add.fullname} is a reserved type name.")
