@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 ##
 # Licensed to the Apache Software Foundation (ASF) under one
@@ -18,8 +18,22 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from __future__ import absolute_import, division, print_function
-
-from avro.tether.tether_task import HTTPRequestor, TaskType, TetherTask, inputProtocol, outputProtocol
+from avro.tether.tether_task import (
+    HTTPRequestor,
+    TaskType,
+    TetherTask,
+    inputProtocol,
+    outputProtocol,
+)
 from avro.tether.tether_task_runner import TaskRunner
 from avro.tether.util import find_port
+
+__all__ = (
+    "HTTPRequestor",
+    "TaskRunner",
+    "TaskType",
+    "TetherTask",
+    "find_port",
+    "inputProtocol",
+    "outputProtocol",
+)
